/* -*- mode: c; c-basic-offset: 4; -*- */
/* vi:set cindent ts=8 sts=4 sw=4: */
#ifndef PLAYLIST_H
#define PLAYLIST_H

/* Arguments to save_playlist() write_song_names_to_file() */
#define OVERWRITE 0
#define ASK_IF_EXISTS 1

struct playlist_entry {
    char *song;			/* name of the song (the filename) */
    char *path;			/* absolute path of the song (included the filename) */
    bool toggled;		/* is the song toggled */
    struct playlist_entry *prev;
    struct playlist_entry *next;
};

extern struct playlist_entry *first_entry;

void interactive_add_dir(struct menu **menu, struct menu **prevmenu, bool * playlist_changed);
int add_dir(const char *path);
void interactive_add_song(struct menu **menu, struct menu **prevmenu, bool * playlist_changed);
void add_song(const char *path);
void interactive_append_playlist(struct menu *menu, bool * playlist_changed);
void free_playlist(struct playlist_entry **first_playlist_entry);
void move_entry(int dstindex, int srcindex);
void interactive_load_playlist(struct menu *menu, char **playlist, bool * playlist_changed);
void interactive_save_playlist(struct menu *menu, char **playlist, bool * playlist_changed);
void interactive_save_playlist_as(struct menu *menu, char **playlist, bool * playlist_changed);
struct playlist_entry *load_playlist(char *playlist, int *num_entries, bool * err);
void remove_entry(struct menu *menu, bool * playlist_changed);
void actually_remove_entry(int index);
int save_playlist(const char *playlist, bool ask_if_exist);
void interactive_write_song_names_to_file(struct menu *menu);
void playlist_search(struct menu *menu, int op);
void toggle_all_entries(bool yes);
void toggle_entry(int index);
void sort_playlist(void);
void reverse_sort_playlist(void);

#endif
